@@ -4,7 +4,7 @@ from enum import Enum
 from core.number.BigFloat import BigFloat
 
 
-class Status(Enum):
+class Status(str, Enum):
     NEW = 'new'
     USED = 'used'
 
@@ -13,5 +13,4 @@ class Status(Enum):
 class PositionSlip:
     instrument: str
     quantity: BigFloat
-    instant: int
     status: Status = field(default=Status.NEW)
